@@ -26,9 +26,9 @@ use Encode qw(encode);
 use YAML qw(Dump);
 use JSON qw();
 
-__PACKAGE__->mk_accessors(qw(to_xml to_hash to_yaml to_json from_xml));
+__PACKAGE__->mk_accessors(qw(to_xml to_hash to_yaml to_json));
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.1';
 
 # Default values
 my $PATH = '/files';
@@ -399,11 +399,6 @@ sub from_xml {
 
    my @files = $xml->find('/augeas/files/file')->get_nodelist();
 
-   if ($#files < 0) {
-      warn "W: The XML document contains no file to restore.";
-      return;
-   }
-
    for my $file (@files) {
       my $path = $file->getAttribute('path');
       my $aug_path = "/files${path}";
@@ -568,7 +563,7 @@ http://augeas.net/ : The Augeas project page
 
 =head1 AUTHOR
 
-RaphaE<euml>l Pinson, E<lt>raphink at cpan dot orgE<gt>
+RaphaE<euml>l Pinson, E<lt>raphink at gmail dot comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
